<?php
/**
* @package CloudWork Canvas Framework
* @subpackage class-cw-metabox.php
* @author Chris Kelley <chris@organicbeemedia.com)
* @author URI: http://cloudworkthemes.com
* @link http://demo.cloudworkthemes.com/tracked
* @license GPL v3
* @license URI http://www.gnu.org/licenses/gpl.html 
* @since 1.0
* @copyright Andrew Norcross (@norcross / andrewnorcross.com)
* @copyright Jared Atchison (@jaredatch / jaredatchison.com)
* @copyright Bill Erickson (@billerickson / billerickson.net)
*
* This script is based off of Custom Metaboxes and Fields by Andrew Norcross,
* Jared Atchison, and Bill Erickson https://github.com/jaredatch/Custom-Metaboxes-and-Fields-for-WordPress
* 
* 	Table of Contents
*	-----------------*
*	
*	Metabox Class, maybe phased out in future versions.
* 
*		class cw_Meta_box_Validate 
*		class cw_Meta_box
* 			__construct
*		add_post_enctype
*		add
* 		add_for_id
*		add_for_page_template
*		show
*		save
*/
 
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Validate value of meta fields
 * Define ALL validation methods inside this class and use the names of these 
 * methods in the definition of meta boxes (key 'validate_func' of each field)
 */
class cw_Meta_Box_Validate {

	
	/**
	 * Check Text
	 * 
	 * @since 1.0
	 * @access public
	 * @param string $text
	 * @return bool
	 */
	function check_text( $text ) {
		
		if ($text != 'hello') {
		
			return false;
		
		}
		
		return true;
	
	}
}


/**
* Create meta boxes
*/
class cw_Meta_Box {
	
	protected $_meta_box;

	
	/**
	 * __construct function.
	 * 
	 * @since 1.0
	 * @access public
	 * @param mixed $meta_box
	 * @return void
	 */
	function __construct( $meta_box ) {
		
		if ( !is_admin() ) {
		
			return;
		
		}
		
		$this->_meta_box = $meta_box;

		$upload = false;
		
		foreach ( $meta_box['fields'] as $value ) {
			
			if ( $value['type'] == 'file' || $value['type'] == 'file_list' ) {
				
				$upload = true;
				
				break;
			
			}
		}
		
		global $pagenow;		
		
		if ( $upload && in_array( $pagenow, array( 'page.php', 'page-new.php', 'post.php', 'post-new.php' ) ) ) {
			
			add_action( 'admin_head', array( &$this, 'add_post_enctype' ) );
		
		}

		add_action( 'admin_menu', array( &$this, 'add' ) );
		
		add_action( 'save_post', array( &$this, 'save' ) );

		add_filter( 'cw_show_on', array( &$this, 'add_for_id' ), 10, 2 );
		
		add_filter( 'cw_show_on', array( &$this, 'add_for_page_template' ), 10, 2 );
	
	}

	
	/**
	 * add_post_enctype function.
	 * 
	 * @since 1.0
	 * @access public
	 * @return string
	 */
	function add_post_enctype() {
		
		echo '<script type="text/javascript">
			jQuery(document).ready(function(){
			jQuery("#post").attr("enctype", "multipart/form-data");
			jQuery("#post").attr("encoding", "multipart/form-data");
		});
		</script>';
	
	}

	
	/**
	 * add function.
	 * 
	 * @since 1.0
	 * @access public
	 * @return void
	 */
	function add() {
	
		$this->_meta_box['context'] = empty($this->_meta_box['context']) ? 'normal' : $this->_meta_box['context'];
	
		$this->_meta_box['priority'] = empty($this->_meta_box['priority']) ? 'high' : $this->_meta_box['priority'];
	
		$this->_meta_box['show_on'] = empty( $this->_meta_box['show_on'] ) ? array('key' => false, 'value' => false) : $this->_meta_box['show_on'];
		
		foreach ( $this->_meta_box['pages'] as $page ) {
			
			if( apply_filters( 'cw_show_on', true, $this->_meta_box ) ){
			
			
				add_meta_box( $this->_meta_box['id'], $this->_meta_box['title'], array(&$this, 'show'), $page, $this->_meta_box['context'], $this->_meta_box['priority']) ;
			}
		}
	}
	
	/**
	 * Show On Filters
	 * Use the 'cw_show_on' filter to further refine the conditions under which a metabox is displayed.
	 * Below you can limit it by ID and page template
	 * 
	 * @since 1.0
	 * @access public
	 * @param mixed $display
	 * @param mixed $meta_box
	 * @return void
	 */
	function add_for_id( $display, $meta_box ) {
	
		if ( 'id' !== $meta_box['show_on']['key'] ){
	
			return $display;

		}
		
		// If we're showing it based on ID, get the current ID					
		if( isset( $_GET['post'] ) ){
		
			$post_id = $_GET['post'];
		
		} elseif( isset( $_POST['post_ID'] ) ){
		
		 $post_id = $_POST['post_ID'];
		
		}
		
		if( !isset( $post_id ) ){
		
			return false;
		
		}
		
		// If value isn't an array, turn it into one	
		$meta_box['show_on']['value'] = !is_array( $meta_box['show_on']['value'] ) ? array( $meta_box['show_on']['value'] ) : $meta_box['show_on']['value'];
		
		// If current page id is in the included array, display the metabox
		if ( in_array( $post_id, $meta_box['show_on']['value'] ) ){
		
			return true;
		
		} else {
			
			return false;
		
		}
	}
	
	/**
	 * add_for_page_template function.
	 * 
	 * @since 1.0
	 * @access public
	 * @param mixed $display
	 * @param mixed $meta_box
	 * @return void
	 */
	function add_for_page_template( $display, $meta_box ) {
	
		if( 'page-template' !== $meta_box['show_on']['key'] ){
					
			return $display;
			
		}
			
		// Get the current ID
		if( isset( $_GET['post'] ) ){
		
		$post_id = $_GET['post'];
		
		} elseif( isset( $_POST['post_ID'] ) ){
		
			$post_id = $_POST['post_ID'];
		
		}
		
		if( !( isset( $post_id ) || is_page() ) ) {
		
		return false;
			
		}
			
		// Get current template
		$current_template = get_post_meta( $post_id, '_wp_page_template', true );
		
		// If value isn't an array, turn it into one	
		$meta_box['show_on']['value'] = !is_array( $meta_box['show_on']['value'] ) ? array( $meta_box['show_on']['value'] ) : $meta_box['show_on']['value'];

		// See if there's a match
		if( in_array( $current_template, $meta_box['show_on']['value'] ) ){
		
			return true;
		
		} else {
		
			return false;
		
		}
	}
	
	
	/**
	 * show function.
	 * 
	 * @since 1.0
	 * @access public
	 * @return string
	 */
	function show() {

		global $post;

		// Use nonce for verification
		echo '<input type="hidden" name="wp_meta_box_nonce" value="', wp_create_nonce( basename(__FILE__) ), '" />';
		echo '<table class="form-table cmb_metabox">';

		foreach ( $this->_meta_box['fields'] as $field ) {
			// Set up blank or default values for empty ones
			if ( !isset( $field['name'] ) ) $field['name'] = '';
			if ( !isset( $field['desc'] ) ) $field['desc'] = '';
			if ( !isset( $field['std'] ) ) $field['std'] = '';
			if ( 'file' == $field['type'] && !isset( $field['allow'] ) ) $field['allow'] = array( 'url', 'attachment' );
			if ( 'file' == $field['type'] && !isset( $field['save_id'] ) )  $field['save_id']  = false;
			if ( 'multicheck' == $field['type'] ) $field['multiple'] = true;  
						
			$meta = get_post_meta( $post->ID, $field['id'], 'multicheck' != $field['type'] /* If multicheck this can be multiple values */ );

			echo '<tr>';
	
			if ( $field['type'] == "title" ) {
				echo '<td colspan="2">';
			} else {
				if( $this->_meta_box['show_names'] == true ) {
					echo '<th style="width:18%"><label for="', $field['id'], '">', $field['name'], '</label></th>';
				}			
				echo '<td>';
			}		
						
			switch ( $field['type'] ) {

				case 'text':
					echo '<input type="text" name="', $field['id'], '" id="', $field['id'], '" value="', '' !== $meta ? $meta : $field['std'], '" />','<p class="cmb_metabox_description">', $field['desc'], '</p>';
					break;
				case 'textarea':
					echo '<textarea name="', $field['id'], '" id="', $field['id'], '" cols="60" rows="10">', '' !== $meta ? $meta : $field['std'], '</textarea>','<p class="cmb_metabox_description">', $field['desc'], '</p>';
					break;

				case 'textarea_code':
					echo '<textarea name="', $field['id'], '" id="', $field['id'], '" cols="60" rows="10" class="cmb_textarea_code">', '' !== $meta ? $meta : $field['std'], '</textarea>','<p class="cmb_metabox_description">', $field['desc'], '</p>';
					break;					
				case 'select':
					if( empty( $meta ) && !empty( $field['std'] ) ) $meta = $field['std'];
					echo '<select name="', $field['id'], '" id="', $field['id'], '">';
					foreach ($field['options'] as $option) {
						echo '<option value="', $option['value'], '"', $meta == $option['value'] ? ' selected="selected"' : '', '>', $option['name'], '</option>';
					}
					echo '</select>';
					echo '<p class="cmb_metabox_description">', $field['desc'], '</p>';
					break;

				case 'radio':
					if( empty( $meta ) && !empty( $field['std'] ) ) $meta = $field['std'];
					echo '<ul>';
					$i = 1;
					foreach ($field['options'] as $option) {
						echo '<li><input type="radio" name="', $field['id'], '" id="', $field['id'], $i,'" value="', $option['value'], '"', $meta == $option['value'] ? ' checked="checked"' : '', ' /><label for="', $field['id'], $i, '">', $option['name'].'</label></li>';
						$i++;
					}
					echo '</ul>';
					echo '<p class="cmb_metabox_description">', $field['desc'], '</p>';
					break;
				case 'checkbox':
					echo '<input type="checkbox" name="', $field['id'], '" id="', $field['id'], '"', $meta ? ' checked="checked"' : '', ' />';
					echo '<span class="cmb_metabox_description">', $field['desc'], '</span>';
					break;
				case 'multicheck':
					echo '<ul>';
					$i = 1;
					foreach ( $field['options'] as $value => $name ) {
						// Append `[]` to the name to get multiple values
						// Use in_array() to check whether the current option should be checked
						echo '<li><input type="checkbox" name="', $field['id'], '[]" id="', $field['id'], $i, '" value="', $value, '"', in_array( $value, $meta ) ? ' checked="checked"' : '', ' /><label for="', $field['id'], $i, '">', $name, '</label></li>';	
						$i++;
					}
					echo '</ul>';
					echo '<span class="cmb_metabox_description">', $field['desc'], '</span>';					
					break;		
				case 'title':
					echo '<h5 class="cmb_metabox_title">', $field['name'], '</h5>';
					echo '<p class="cmb_metabox_description">', $field['desc'], '</p>';
					break;

				default:
			}
			
			echo '</td>','</tr>';
		}
		echo '</table>';
	}
	
	
	/**
	 * save function.
	 * 
	 * @since 1.0
	 * @access public
	 * @param mixed $post_id
	 * @return void
	 */
	function save( $post_id)  {

		// verify nonce
		if ( ! isset( $_POST['wp_meta_box_nonce'] ) || !wp_verify_nonce( $_POST['wp_meta_box_nonce'], basename(__FILE__) ) ) {
			return $post_id;
		}

		// check autosave
		if ( defined('DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return $post_id;
		}

		// check permissions
		if ( 'page' == $_POST['post_type'] ) {
			if ( !current_user_can( 'edit_page', $post_id ) ) {
				return $post_id;
			}
		} elseif ( !current_user_can( 'edit_post', $post_id ) ) {
			return $post_id;
		}

		foreach ( $this->_meta_box['fields'] as $value ) {
			$name = $value['id'];			

			if ( ! isset( $value['multiple'] ) )
				$value['multiple'] = ( 'multicheck' == $value['type'] ) ? true : false;    
				  
			$old = get_post_meta( $post_id, $name, !$value['multiple'] /* If multicheck this can be multiple values */ );
			$new = isset( $_POST[$value['id']] ) ? $_POST[$value['id']] : null;
			
			if ( in_array( $value['type'], array( 'taxonomy_select', 'taxonomy_radio', 'taxonomy_multicheck' ) ) )  {	
				$new = wp_set_object_terms( $post_id, $new, $value['taxonomy'] );	
			}
			
			if ( ($value['type'] == 'textarea') || ($value['type'] == 'text') ) {
				$new = htmlspecialchars( $new );
			}

			if ( ($value['type'] == 'textarea_code') ) {
				$new = htmlspecialchars_decode( $new );
			}
						
			$new = apply_filters('cmb_validate_' . $value['type'], $new, $post_id, $value);			
			
			// validate meta value
			if ( isset( $value['validate_func']) ) {
				$ok = call_user_func( array( 'cw_Meta_Box_Validate', $value['validate_func']), $new );
				if ( $ok === false ) { // pass away when meta value is invalid
					continue;
				}
			} elseif ( $value['multiple'] ) {
				delete_post_meta( $post_id, $name );	
				if ( !empty( $new ) ) {
					foreach ( $new as $add_new ) {
						add_post_meta( $post_id, $name, $add_new, false );
					}
				}			
			} elseif ( '' !== $new && $new != $old  ) {
				update_post_meta( $post_id, $name, $new );
			} elseif ( '' == $new ) {
				delete_post_meta( $post_id, $name );
			}
			
			if ( 'file' == $value['type'] ) {
				$name = $value['id'] . "_id";
				$old = get_post_meta( $post_id, $name, !$value['multiple'] /* If multicheck this can be multiple values */ );
				if ( isset( $value['save_id'] ) && $value['save_id'] ) {
					$new = isset( $_POST[$name] ) ? $_POST[$name] : null;
				} else {
					$new = "";
				}

				if ( $new && $new != $old ) {
					update_post_meta( $post_id, $name, $new );
				} elseif ( '' == $new && $old ) {
					delete_post_meta( $post_id, $name, $old );
				}
			}			
		}
	}
}

?>