<?php
/**
* @package CloudWork Canvas Framework
* @subpackage cloudwork-loader.php
* @author Chris Kelley <chris@organicbeemedia.com)
* @author URI: http://cloudworkthemes.com
* @link http://demo.cloudworkthemes.com/tracked
* @license GPL v3
* @license URI http://www.gnu.org/licenses/gpl.html 
* @since 1.0
*
*  	 Copyright (C) 2013  Chris Kelley (chris@organicbeemedia.com)
*
*    This program is free software: you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation, either version 3 of the License, or
*    (at your option) any later version.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU General Public License for more details.
*
*    You should have received a copy of the GNU General Public License
*    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
* 	 Some rights reserved. See COPYING, AUTHORS.
*
* 	Table of Contents
*	-----------------
*
*	Loads the core framework files
*
*		Class cloudwork_themes_Scripts
*		instance
*		constants
*		includes
*		load_textdomain
*/
 
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

if ( !class_exists( 'cw_Canvas' ) ) :

final class cw_Canvas{
	
	static $instance;

	/**
	 * Return one true instance of Cloudwork Canvas Class.
	 * 
	 * @since 1.0
	 * @access public
	 * @static
	 * @return void
	 */
	public static function instance(){
		
		if ( ! isset( self::$instance ) ) {
		
			self::$instance = new cw_Canvas;
			
			self::$instance->constants();
			
			self::$instance->includes();
						
			self::$instance->load_textdomain();
		
		}
		
		return self::$instance;
	
	}
		
	
	/**
	 * Sets up the environment.
	 *
	 * @since 1.0 
	 * @access private
	 * @return void
	 */
	private function constants(){
	
	
		if( !defined( 'CW_CANVAS_VERSION' )){

			define('CW_CANVAS_VERSION', '1.0');
		
		}
		
		if( !defined( 'THEMENAME' )){
	
			define('THEMENAME', wp_get_theme()->display('Name'));
		
		}
		
		if( !defined( 'THEMEVERSION' )){
		
			define('THEMEVERSION', wp_get_theme()->display('Version'));
		
		}
		
		if( !defined( 'THEME_DIR' )){
		
			/* Sets the path to the parent theme directory. */
			define( 'THEME_DIR', get_template_directory() );
		
		}
		
		if( !defined( 'THEME_URI' )){

			/* Sets the path to the parent theme directory URI. */
			define( 'THEME_URI', get_template_directory_uri() );
		
		}
		
		if( is_child_theme() ){
			
			if( !defined( 'CHILD_THEME_DIR' )){
		
				define('CHILD_THEME_DIR', get_stylesheet_directory() );
			
			}
			
			if( !defined( 'CHILD_THEME_URI' )){
		
				define( 'CHILD_THEME_URI', get_stylesheet_directory_uri() );
		
			}	
		
		}
		
		if( !defined( 'CW_CORE' )){
			
			/* Sets the path to the includes directory. */
			define( 'CW_CORE', trailingslashit( THEME_DIR ) . 'functions' );
		
		}
		
		if( !defined( 'CW_LIB' )){
		
			define( 'CW_LIB', trailingslashit( CW_CORE ) . 'library' );
		
		}
		
		if( !defined( 'CW_INC' )){
		
			/* Sets the path to the includes directory. */
			define( 'CW_INC', trailingslashit( THEME_DIR ) . 'includes' );
		
		}
		
		if( !defined( 'CW_LANG' )){

			/* Sets the path to the Lang directory. */
			define( 'CW_LANG', trailingslashit( THEME_DIR ) . 'language' );
		
		}
		
		if( !defined( 'CW_MEDIA' )){

			/* Sets the path to the Media directory. */
			define( 'CW_MEDIA', trailingslashit( THEME_URI ) . 'media' );
		
		}
		
		if( !defined( 'CW_CSS' )){
		
			define( 'CW_CSS', trailingslashit( CW_MEDIA ) . 'css' );
		
		}
		
		if( !defined( 'CW_ADMIN_CSS' )){
		
			define( 'CW_ADMIN_CSS', trailingslashit( CW_CSS ) . 'admin' );
		
		}
		
		if( !defined( 'CW_JS' )){
		
			define( 'CW_JS', trailingslashit( CW_MEDIA ) . 'scripts' );		
	
		}
		
		if( !defined( 'CW_FLASH' )){

			define( 'CW_FLASH', trailingslashit( CW_MEDIA ) . 'scripts' );	
		
		}
		
		if( !defined( 'CW_ADMIN_JS' )){

			define( 'CW_ADMIN_JS', trailingslashit( CW_JS ) . 'admin' );
		
		}
		if( !defined( 'CW_IMAGES' )){
		
			define( 'CW_IMAGES', trailingslashit( CW_MEDIA ) . 'images' );

		}
	}
	
	/**
	 * Include core files.
	 *
	 * @since 1.0 
	 * @access private
	 * @return void
	 */
	private function includes(){
	
		require_once trailingslashit( CW_LIB ) . 'class-tgm-plugin-activation.php';

		require_once trailingslashit( CW_CORE ) . 'default-hooks.php';
	
		require_once trailingslashit( CW_CORE ) . 'utility-functions.php';

		require_once trailingslashit( CW_CORE ) . 'class-cw-customizer-framework.php';
	
		require_once trailingslashit( CW_CORE ) . 'core-scripts.php';

		require_once trailingslashit( CW_CORE ) . 'class-cw-metabox.php';

	}
	
	/**
	 * Loads the text domain for themes.
	 * 
	 * @since 1.0
	 * @access public
	 * @return void
	 * @todo make filterable for better compat goal: 1.1
	 */
	public function load_textdomain(){
		
		load_theme_textdomain('cloudwork_themes', false, CW_LANG );

	}
	

}//Ends Class

endif; //end if 
