<?php
/**
* @package CloudWork Canvas Framework
* @subpackage core-scripts.php
* @author Chris Kelley <chris@organicbeemedia.com)
* @author URI: http://cloudworkthemes.com
* @link http://demo.cloudworkthemes.com/tracked
* @license GPL v3
* @license URI http://www.gnu.org/licenses/gpl.html 
* @since 1.0
*
*  	 Copyright (C) 2013  Chris Kelley (chris@organicbeemedia.com)
*
*    This program is free software: you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation, either version 3 of the License, or
*    (at your option) any later version.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU General Public License for more details.
*
*    You should have received a copy of the GNU General Public License
*    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
* 	 Some rights reserved. See COPYING, AUTHORS.
*
* 	Table of Contents
*	-----------------
*
*	This file loads all scripts for the admin and registers all bundled scripts
*
*		Class cw_Canvas_Scripts
*			__construct
*			register_admin_scripts
*			admin_enqueue_scripts
*			register_bundled_scripts
*/

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

if ( !class_exists( 'cw_Canvas_Scripts' ) ) :

class cw_Canvas_Scripts{
	
	/**
	 * Contstruct Function
	 * 
	 * @since 1.0
	 * @access public
	 * @return void
	 */
	function __construct(){
		
		add_action('admin_init', array( &$this , 'register_admin_scripts' ) );
		
		
		add_action( 'init', array( &$this , 'register_bundled_scripts' ) );
		
	}
	
	/**
	 * Register Admin Scripts
	 *
	 * Metaboxes are used for pre 3.6 post types, enqueue the script in compat.
	 * 
	 * @since 1.0
	 * @access public
	 * @return void
	 */
	function register_admin_scripts(){
				
		wp_register_script( 'cw-metabox', trailingslashit( CW_ADMIN_JS ) . 'cw.metabox.js', array( 'jquery' ) );

	}

	/**
	 * Register CloudWork Canvas Core Scripts
	 *
	 * This registers scripts bundled with the core, not all themes will use all scripts.
	 * 
	 * @since 1.0
	 * @access public
	 * @return void
	 */
	function register_bundled_scripts(){

		wp_register_script( 'cw-less', trailingslashit( CW_JS ) . 'less-1.3.3.js', array(), '1.3.3' , true );
	
		wp_register_script( 'cw-tipsy', trailingslashit( CW_JS ) . 'jquery.tipsy.js', array('jquery'), THEMEVERSION , true );
	
		wp_register_script( 'cw-audiojs', trailingslashit( CW_JS ) . 'audio.min.js', array('jquery'), THEMEVERSION , true );
		
		wp_register_script( 'cw-fitvid', trailingslashit( CW_JS ) . 'jquery.fitvids.js', array('jquery'), THEMEVERSION , true );
		
		wp_register_script( 'cw-gestures', trailingslashit( CW_JS ) . 'jgestures.min.js', array('jquery'), '1.0' , true );

		wp_register_script( 'cw-history', trailingslashit( CW_JS ) . 'jquery.history.js', array('jquery'), '1.0' , true );

		wp_register_script( 'cw-preload', trailingslashit( CW_JS ) . 'jquery.imgpreload.min.js', array('jquery'), '1.0' , true );

		wp_register_script( 'cw-flexislider', trailingslashit( CW_JS ) . 'jquery.flexslider.min.js', array('jquery'), '2.1' , true );

	}
	
}//end class

endif; //end if 

$cw_core_scripts = new cw_Canvas_Scripts();

?>