<?php
/**
* @package CloudWork Canvas Framework
* @subpackage utility-functions.php
* @author Chris Kelley <chris@organicbeemedia.com)
* @author URI: http://cloudworkthemes.com
* @link http://demo.cloudworkthemes.com/tracked
* @license GPL v3
* @license URI http://www.gnu.org/licenses/gpl.html 
* @since 1.0
*
*  	 Copyright (C) 2013  Chris Kelley (chris@organicbeemedia.com)
*
*    This program is free software: you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation, either version 3 of the License, or
*    (at your option) any later version.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU General Public License for more details.
*
*    You should have received a copy of the GNU General Public License
*    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
* 	 Some rights reserved. See COPYING, AUTHORS.
*
* 	Table of Contents
*	-----------------
*
*/

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

//
add_action( 'after_switch_theme', 'cloudwork_theme_install');

/**
 * Theme install function, similar to the plugin_activation_hook, its only ran once.
 *
 * @since 1.0
 * @access public
 * @return void
 */
function cloudwork_theme_install() {

	global $wp_version, $wp_rewrite;

	//flush rewrites
	$wp_rewrite->flush_rules();
	
	if ( version_compare($wp_version, '3.5', '<' ) ) {	
		
		switch_theme( 'twentytwelve' );
		
		wp_die( THEMENAME .' requires WordPress 3.5 or higher, the theme has been deactivated, Twenty Twelve is your active theme now! Please upgrade <a href="http://wordpress.org">WordPress</a> and try again.' );
	}
	
	do_action('cloudwork_theme_install');
	
}

/**
 *  Function to check if its older than 3.6, for post format compatibility.
 * 
 * @access public
 * @return void
 */
function is_cw_old_post_formats(){
	
	global $wp_version;
	
	if( version_compare($wp_version, '3.6', '>' )  ){
		
		return true;
		
	} else {
		
		return false;
	
	}
	
}
/**
 * Check if page template is active.
 *
 * @since 1.0
 * @access public
 * @param string $pagetemplate (default: '')
 * @return bool
 */
function is_cw_template($pagetemplate = '') {

	global $wpdb;

	$cw_page_check = $wpdb->query($wpdb->prepare( "SELECT meta_key FROM $wpdb->postmeta WHERE meta_key = '_wp_page_template' AND meta_value = %s", $pagetemplate));

	if ($cw_page_check) {
	
		return true;
		
	} else {
	
		return false;
		
	}
}
/**
 * cw_update_meta_key function.
 * 
 * @access public
 * @param mixed $new_metakey
 * @param mixed $old_metakey
 * @return void
 */
function cw_update_meta_key( $new_metakey, $old_metakey ) {
  
    global $wpdb;
 
    $update = $wpdb->query($wpdb->prepare("UPDATE ".$wpdb->postmeta." SET meta_key = %s WHERE meta_key = %s ",$new_metakey, $old_metakey ));
      
    return $update;

}

/**
 * Function to get post format and decides what template to get.
 *
 * @since 1.0
 * @access public
 * @return void
 */
function cw_get_post_format() {

	if ( is_page() ) {
	
		$format = 'page';
		
	} else {
	
		$format = get_post_format();
		
		if ( false === $format )
		
			$format = 'standard';
	}

	get_template_part( 'content', $format );

}
/**
 * Built in Pagination function 1,2,3,4,5 etc..
 *
 * @since 1.0
 * @access public
 * @param string $pages (default: '')
 * @param int $range (default: 2)
 * @return string
 */
function cw_pagination($pages = '', $range = 2) {
	
	global $paged;
	
	$output ='';

	$showitems = ($range * 2)+1;

	if (empty($paged)) {
	
	$paged = 1;
	
	}

	if ($pages == '') {
	
		global $wp_query;
		
		$pages = $wp_query->max_num_pages;
		
		if (!$pages) { 
		
		$pages = 1;
		
		}
	}

	if (1 != $pages) {
	
		$output .='<nav class="pagination"><span>Page ' . $paged . ' of ' .$pages. '</span>';
		
		if ($paged > 2 && $paged > $range+1 && $showitems < $pages) 
		
			$output .='<a href="' . get_pagenum_link(1) . '">&laquo; First</a>';
		
		if ($paged > 1 && $showitems < $pages) 
		
			$output .='<a href="' . get_pagenum_link($paged - 1).'">&lsaquo; Previous</a>';

		for ($i=1; $i <= $pages; $i++) {
		
			if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems )) {
		
				$output .= ($paged == $i)?   '<span class="current">'.$i.'</span>':'<a href="'.get_pagenum_link($i).'" class="inactive">'.$i.'</a>';
		
			}
		}

		if ($paged < $pages && $showitems < $pages){
		
		 $output .='<a href="'.get_pagenum_link($paged + 1).'">Next &rsaquo;</a>';
		
		}
		
		if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) {
		
		$output .='<a href="'.get_pagenum_link($pages).'">Last &raquo;</a>';
		
		}

		$output .='</nav>';
	}
	
	return apply_filters( 'cw_pagination_output', $output );
		
}


/**
 * Function to display next and previous links for pagination.
 *
 * @since 1.0
 * @access public
 * @param mixed $nav_id
 * @return string
 */
function cw_prev_next_links() {

	global $wp_query;
	
	$output = '';

	if ( $wp_query->max_num_pages > 1 ) { 
	
	$output .= '<nav class="pagination">';
	
	$output .='<div class="nav-previous">' . next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'cloudwork_themes' ) ).'</div>';
	
	$output .='<div class="nav-next">' . previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'cloudwork_themes' ) ). '</div>';
	
	$output .='</nav>';
	
	}
	
	return apply_filters( 'cw_prev_next_output', $output );

}

//
add_filter( 'the_content', 'cw_clean_gallery_shortcode' );

/**
 * Checks the Gallery Post formats and removes the shortcode from the content to prevent
 * users from having duplicated galleries if they use "insert into post"
 *
 * @since 1.0
 * @access public
 * @param mixed $content
 * @return mixed
 */
 
function cw_clean_gallery_shortcode( $content )
{
	global $post;

	/* make sure its only gallery post format*/
	if ( has_post_format('gallery') ) {
			
		$pattern = get_shortcode_regex();
		
		preg_match('/'.$pattern.'/s', $content, $matches);
		
		if ( isset($matches[2]) && is_array($matches) && $matches[2] == 'gallery') {
		
			//shortcode is being used
			$content = str_replace( $matches['0'], '', $content );
		
		}
	}
	
	return $content;

}

/**
 * This replaces the default wp_link_pages and wraps the active page with a span(note themeforest rejects themes using this must require wp_link_pages)
 * 
 * @since 1.0
 * @access public
 * @param string $arg (default: '')
 * @return void
 * @todo add filters
 * @todo submit patch to WordPress trac
 */
function cw_link_pages($arg =''){
	
	$defaults = array(
	'before' => '<nav class="pagination"><span>' . __('Pages:', 'cloudwork_themes') . '</span>', 
	'after' => '</nav>',
	'link_before' => '',
	'link_after' => '',
	'next_or_number' => 'number',
	'nextpagelink' => __('Next page', 'cloudwork_themes'),
	'previouspagelink' => __('Previous page', 'cloudwork_themes'),
	'pagelink' => '%',
	'echo' => 1
	);
	
	$args ='';
	
	$r = wp_parse_args( $args, $defaults );
	
	$r = apply_filters( 'wp_link_pages_args', $r );
	
	extract( $r, EXTR_SKIP );

	global $page, $numpages, $multipage, $more, $pagenow;

	$output = '';
	
	if ( $multipage ) {
	
		if ( 'number' == $next_or_number ) {
		
			$output .= $before;
			
			for ( $i = 1; $i < ( $numpages + 1 ); $i = $i + 1 ) {
			
				$j = str_replace( '%', $i, $pagelink );
				
				$output .= ' ';
				
				if ( $i != $page || ( ( ! $more ) && ( $page == 1 ) ) )
				
					$output .= _wp_link_page( $i );
					
				else
				
					$output .= '<span class="current">';

				$output .= $link_before . $j . $link_after;
				
				if ( $i != $page || ( ( ! $more ) && ( $page == 1 ) ) )
				
					$output .= '</a>';
					
				else
				
					$output .= '</span>';
			}
			
			$output .= $after;
			
		} else {
		
			if ( $more ) {
			
				$output .= $before;
				
				$i = $page - 1;
				
				if ( $i && $more ) {
				
					$output .= _wp_link_page( $i );
					
					$output .= $link_before . $previouspagelink . $link_after . '</a>';
					
				}
				
				$i = $page + 1;
				
				if ( $i <= $numpages && $more ) {
				
					$output .= _wp_link_page( $i );
					
					$output .= $link_before . $nextpagelink . $link_after . '</a>';
					
				}
				
				$output .= $after;
			}
		}
	}

	if ( $echo ){
	
		echo $output;
	
	}
	
	//return $output;
	return $output;

}

//Browser Body Classes
add_filter( 'body_class', 'cw_body_class' );

/**
 * Adds a bit more control of the body class.
 *
 * @since 1.0
 * @access public
 * @param mixed $classes
 * @return void
 * @todo add better browser support
 */
function cw_body_class( $classes ) {

	// A little Browser detection shall we?
	$browser = $_SERVER[ 'HTTP_USER_AGENT' ];
	
	// Mac, PC ...or Linux
	if ( preg_match( "/Mac/", $browser ) ) {
	
		$classes[] = 'mac';

	}  elseif ( preg_match( "/Windows NT 6.2/i", $browser ) ) {
	
		$classes[] = 'win8';
		
	}elseif ( preg_match( "/Windows/", $browser ) ) {
	
		$classes[] = 'windows';

	} elseif ( preg_match( "/Linux/", $browser ) ) {
	
		$classes[] = 'linux';

	} else {
	
		$classes[] = 'unknown-os';
	}



	// Checks browsers in this order: Chrome, Safari, Opera, MSIE, FF
	if ( preg_match( "/Chrome/", $browser ) ) {
	
		$classes[] = 'chrome';

		preg_match( "/Chrome\/(\d.\d)/si", $browser, $matches);
		
		if(isset( $matches[1])){
		
		$classesh_version = 'ch' . str_replace( '.', '-', $matches[1] );
		
		$classes[] = $classesh_version;

		}
		
	} elseif ( preg_match( "/Safari/", $browser ) ) {
	
		$classes[] = 'safari';

		preg_match( "/Version\/(\d.\d)/si", $browser, $matches);
		
		if(isset( $matches[1])){
		
			$sf_version = 'sf' . str_replace( '.', '-', $matches[1] );
	
			$classes[] = $sf_version;
		
		}
	} elseif ( preg_match( "/Opera/", $browser ) ) {
	
		$classes[] = 'opera';

		preg_match( "/Opera\/(\d.\d)/si", $browser, $matches);
		
		if(isset( $matches[1])){
		
		$op_version = 'op' . str_replace( '.', '-', $matches[1] );
		
		$classes[] = $op_version;

		}
	} elseif ( preg_match( "/MSIE/", $browser ) ) {
	
		$classes[] = 'msie';

		if ( preg_match( "/MSIE 8.0/", $browser ) ) {
		
			$classes[] = 'ie8';
			
		} elseif ( preg_match( "/MSIE 9.0/", $browser ) ) {
		
			$classes[] = 'ie9';
			
		} elseif ( preg_match( "/MSIE 10.0/", $browser ) ) {
		
			$classes[] = 'ie10';
			
		}

	} elseif ( preg_match( "/Firefox/", $browser ) && preg_match( "/Gecko/", $browser ) ) {
	
		$classes[] = 'firefox';

		preg_match( "/Firefox\/(\d)/si", $browser, $matches);
		
		if(isset( $matches[1])){
		
			$ff_version = 'ff' . str_replace( '.', '-', $matches[1] );
		
			$classes[] = $ff_version;
		
		}
		
	} else {
	
		$classes[] = 'unknown-browser';
		
	}

	return $classes;
	
}
?>