<?php
/**
* @package Tracked
* @subpackage theme-comments.php
* @author Chris Kelley <chris@organicbeemedia.com)
* @author URI: http://cloudworkthemes.com
* @link http://demo.cloudworkthemes.com/tracked
* @license GPL v3
* @license URI http://www.gnu.org/licenses/gpl.html 
* @since 1.0
*
*  	 Copyright (C) 2013  Chris Kelley (chris@organicbeemedia.com)
*
*    This program is free software: you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation, either version 3 of the License, or
*    (at your option) any later version.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU General Public License for more details.
*
*    You should have received a copy of the GNU General Public License
*    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
* 	 Some rights reserved. See COPYING, AUTHORS.
*
* 	Table of Contents
*	-----------------
*
*		cw_comment 
*		cw_comment_form 
*/

/**
 * Cloudwork comment function
 * 
 * @since 1.0
 * @access public
 * @param mixed $comment
 * @param mixed $args
 * @param mixed $depth
 * @return void
 */
function cw_comment( $comment, $args, $depth ) {

	$GLOBALS['comment'] = $comment;
	
	switch ( $comment->comment_type ) :
		
		case 'pingback' :
		
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	
	<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
		
		<p><?php _e( 'Pingback:', 'cloudwork_themes' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Edit)', 'cloudwork_themes' ), '<span class="edit-link">', '</span>' ); ?></p>

	<?php
			
			break;
		
		default :
		
		global $post;
	?>
	
	<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
		
		<article class="comment">
				
				<div class="comment-avatar">
				
				<?php echo get_avatar( $comment, 75 );?>	
				
				</div>
				
		<section class="comment-content">

			<header class="comment-meta comment-author vcard">
			<h5 class="comment-author">
			<?php		printf( '<cite class="fn">%1$s %2$s</cite>',
					
						get_comment_author_link(),
					
						// If current post author is also comment author, make it known visually.
						( $comment->user_id === $post->post_author ) ? '<span> ' . __( 'Post author', 'cloudwork_themes' ) . '</span>' : ''
	
					);		
				?>				<span>says</span></h5>


			</header><!-- .comment-meta -->
			
			<div class="comment-body">

			<?php if ( '0' == $comment->comment_approved ) : ?>
				
				<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'cloudwork_themes' ); ?></p>
			
			<?php endif; ?>

			
				<?php comment_text(); ?>
			
				
				</div>
			</section><!-- .comment-content -->
			<footer class="comment-foot">
			
					<div class="time">
						<?php 					printf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
					
						esc_url( get_comment_link( $comment->comment_ID ) ),
					
						get_comment_time( 'c' ),
					
						/* translators: 1: date, 2: time */
					
						sprintf( __( '%1$s at %2$s', 'cloudwork_themes' ), get_comment_date(), get_comment_time() )
					); ?>
					</div>
			<ul class="comment-links">
				
				<li><?php edit_comment_link( __( 'Edit', 'cloudwork_themes' ) ); ?></li>
				<li><?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'cloudwork_themes' ), 'after' => '', 'depth' => $depth, 'max_depth' =>$args['max_depth'] ) ) ); ?></li>
			
			</ul>
			</footer>
		</article>
	
	<?php
	
		break;
	
	endswitch; 
}


//

add_filter('comment_form_defaults', 'cw_comment_form');

/**
 * Change the Comment form defaults
 * 
 * @since 1.0
 * @access public
 * @param mixed $form_options
 * @param mixed $post_id (default: null)
 * @return string
 */
function cw_comment_form($form_options, $post_id = null) {	

	global $id;

	if ( null === $post_id ) {
	
		$post_id = $id;
	
	} else {
	
		$id = $post_id;
	
	}
	
	$commenter = wp_get_current_commenter();
	
	$user = wp_get_current_user();
	
	$user_identity = $user->exists() ? $user->display_name : '';

	$req = get_option( 'require_name_email' );
	
	$aria_req = ( $req ? " aria-required='true'" : '' );
    
    // Fields Array
    $fields = array(
		'author' => '<p class="comment-form-author"><label>'. __( 'Name', 'cloudwork_themes' ) .''. ( $req ? '*' : '' ) .'</label><input id="author" name="author" type="text" placeholder="'. __( 'John Doe', 'cloudwork_themes' ) .'" size="30"' . $aria_req . ' /></p>',
		'email'  => '<p class="comment-form-email"><label>'. __( 'Email', 'cloudwork_themes' ) .''. ( $req ? '*' : '' ) .'</label><input id="email" name="email" type="text" placeholder="'. __( 'name@email.com', 'cloudwork_themes' ) .'" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' /></p>',
		'url'    => '<p class="comment-form-url"><label>'. __( 'Website', 'cloudwork_themes' ) .'</label><input id="url" name="url" type="text" placeholder="'. __( 'http://', 'cloudwork_themes' ) .'" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>',

    );
	$required_text = sprintf( ' ' . __('Required fields are marked %s', 'cloudwork_themes'), '<span class="required">*</span>' );

    // Form Options Array
    $form_options = array(
		'fields'               => apply_filters( 'comment_form_default_fields', $fields ),
		'comment_field'        => '<p class="comment-form-comment"><label>'. __( 'Message', 'cloudwork_themes' ) .'</label><textarea id="comment" name="comment" cols="45" placeholder="'. __( 'Leave a reply', 'cloudwork_themes' ) .'" rows="8" aria-required="true"></textarea></p>',
		'must_log_in'          => '<p class="must-log-in">' . sprintf( __( 'You must be <a href="%s">logged in</a> to post a comment.' ), wp_login_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ) . '</p>',
		'logged_in_as'         => '<p class="logged-in-as">' . sprintf( __( 'Logged in as <a href="%1$s">%2$s</a>. <a href="%3$s" title="Log out of this account">Log out?</a>' ), get_edit_user_link(), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ) . '</p>',
		'comment_notes_before' => '<p class="comment-notes">' . __( 'Your email address will not be published.', 'cloudwork_themes' ) . ( $req ? $required_text : '' ) . '</p>',
		'comment_notes_after'  => '<p class="form-allowed-tags">' . sprintf( __( 'You may use these <abbr title="HyperText Markup Language">HTML</abbr> tags and attributes: %s' ), ' <code>' . allowed_tags() . '</code>' ) . '</p>',
		'id_form'              => 'comment_form',
		'id_submit'            => 'submit',
		'title_reply'          => __( 'Leave a Reply', 'cloudwork_themes' ),
		'title_reply_to'       => __( 'Leave a Reply to %s', 'cloudwork_themes' ),
		'cancel_reply_link'    => __( 'Cancel reply', 'cloudwork_themes' ),
		'label_submit'         => __( 'Post Comment', 'cloudwork_themes' ),
    );

    return $form_options;
}
?>