<?php
/**
* @package Tracked
* @subpackage theme-functions.php
* @author Chris Kelley <chris@organicbeemedia.com)
* @author URI: http://cloudworkthemes.com
* @link http://demo.cloudworkthemes.com/tracked
* @license GPL v3
* @license URI http://www.gnu.org/licenses/gpl.html 
* @since 1.0
*
*  	 Copyright (C) 2013  Chris Kelley (chris@organicbeemedia.com)
*
*    This program is free software: you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation, either version 3 of the License, or
*    (at your option) any later version.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU General Public License for more details.
*
*    You should have received a copy of the GNU General Public License
*    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
* 	 Some rights reserved. See COPYING, AUTHORS.
*
* 	Table of Contents
*	-----------------
*
*
*
*
*
*
*/

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

//add_action('cw_content', 'cw_post_content');

function cw_post_content(){
	
	if( cw_get_option('cw_display_excerpt') === 1 && ! is_singular() ){
		
		the_excerpt();
		
	} else {
		
		the_content();
	}
}
/**
 * Fallback function if Menu isnt set 
 * 
 * @since 1.0
 * @access public
 * @return void
 */
function cw_page_menu() {

	echo '<nav id="main-nav"><ul id="side-menu" class="side-menu"><li><a href="'.get_bloginfo('url').'">Home</a></li>';

	echo wp_list_pages('title_li=');

	echo '</ul></nav>';

}
add_action('init', 'cw_widgets_init');
/**
 * Registers Sidebar/Widgets
 *
 * @access public
 * @return void
 * @since 1.0
 */
function cw_widgets_init() {

	register_sidebar( array(
			'name' => __( 'Sidebar Page', 'cloudwork_themes' ),
			'id' => 'sidebar-widgets',
			'description' => __( 'Appears on the sidebar', 'cloudwork_themes' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget' => '</div></section>',
			'before_title' => '<h3 class="side-widget-title icon-plus">',
			'after_title' => '</h3><div class="side-widget-content">',
		) );
	
}


// if no title then add widget content wrapper to before widget
add_filter( 'dynamic_sidebar_params', 'cw_check_sidebar_params' );
function cw_check_sidebar_params( $params ) {
    global $wp_registered_widgets;

    $settings_getter = $wp_registered_widgets[ $params[0]['widget_id'] ]['callback'][0];
    $settings = $settings_getter->get_settings();
    $settings = $settings[ $params[1]['number'] ];

    if ( $params[0][ 'after_widget' ] == '</div></section>' && isset( $settings[ 'title' ] ) && empty( $settings[ 'title' ] ) )
        $params[0][ 'before_widget' ] .= '<div class="side-widget-content-notitle">';

    return $params;
}

//
add_action('cw_logo', 'cw_display_logo');
/**
 * Function used to display logo checks for retina image.
 * 
 * @since 1.0
 * @access public
 * @return void
 */
function cw_display_logo(){


		echo '<h1 class="site-title">';
		
		if ( cw_get_option('cw-logo') && cw_get_option('cw-retina-logo') == '1' ) { 
		
			list($width, $height) = getimagesize(cw_get_option('cw-logo'));
				
				$width = ($width / 2);
				
				$height = ($height / 2);
			
				echo '<a href="'. home_url().'"><img src="'. cw_get_option('cw-logo') .'" width="'. $width .'" height="'. $height .'" alt="' . get_bloginfo('name') . '" /></a>'; 
			
		} elseif(cw_get_option('cw-logo')){
			
						echo '<a href="'. home_url().'"><img src="'. cw_get_option('cw-logo') .'" alt="' . get_bloginfo('name') . '"></a>'; 
			
		}else {
			
			echo '<a href="'. home_url().'/">'. get_bloginfo('name').'</a>';
				
		 } 
		
		echo '</h1>';
	
}


//Filter Thumbnail Output
add_filter( 'post_thumbnail_html', 'cw_post_image_html', 10, 3 );

/**
 * Modify the post thumbnail HTML, wraps a URL
 *
 * @since 1.0
 * @access public
 * @param mixed $html
 * @param mixed $post_id
 * @return void
 */
function cw_post_image_html( $html, $post_id ) {

	$html = '<a href="' . get_permalink( $post_id ) . '" title="' . esc_attr( get_post_field( 'post_title', $post_id ) ) . '">' . $html . '</a>';
	
	return $html;

}

/**
 * Content Navigation controlled by the Theme Options.
 *
 * @since 1.0
 * @access public
 * @return string
 */
function cw_content_nav()
{

	$cwpagition = cw_get_option('cw-pagination', 'no entry' );

	switch ( $cwpagition ) {

	case 'next':

		echo cw_prev_next_links();

		break;

	case 'numerical':

		echo cw_pagination();

		break;
	}

}


add_action('cw_title', 'cw_title_output');

/**
 * cw_title_output function.
 * 
 * @since 1.1
 * @access public
 * @return void
 */
function cw_title_output(){
	
	$output = wp_title( '|', true, 'right' ) . bloginfo( 'name' ); 

	
	return $output;
}

add_filter('the_password_form', 'cw_password_form');
	

/**
 * Modifies the output of the password form on posts.
 * 
 * @since 1.0
 * @access public
 * @param mixed $output
 * @return void
 */
function cw_password_form( $output ) {
	$post = get_post();
	$label = 'pwbox-' . ( empty($post->ID) ? rand() : $post->ID );
	$output = '	<p>' . __("This post is password protected. To view it please enter your password below:", 'cloudwork_themes') . '</p>
<form class="cw-password-form" action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post">
	<input type="password" class="password-input" name="post_password" id="' . $label . '" placeholder="'. __('Enter your password', 'cloudwork_themes') .'"/><button type="submit" name="Submit" value="' . esc_attr__('Submit') . '" >' . __('Submit', 'cloudwork_themes') . '</buton>
</form>';
	return $output;
}

add_filter( 'excerpt_length', 'cw_excerpt_length' );
/**
 * Excerpt Length.
 *
 * @since 1.0
 * @access public
 * @param mixed $length
 * @return void
 */
function cw_excerpt_length( $length ) {

	return cw_get_option('cw_excerpt_length');

}


add_filter('excerpt_more', 'cw_excerpt_more');

/**
 * Changes the text and adds a link for the excerpt more.
 *
 * @since 1.0
 * @access public
 * @param mixed $more
 * @return void
 */
function cw_excerpt_more($more) {

	global $post;

	if ( cw_get_option('cw_content_text')) {

		return '<p><a class="more-link" href="'. get_permalink($post->ID) . '">'. cw_get_option('cw_content_text') . '<i class="icon-right-open-big"></i></a></p>';

	} else {

		return '';
		
	}
}
?>