<?php
/**
* @package Tracked
* @subpackage theme-options.php
* @author Chris Kelley <chris@organicbeemedia.com)
* @author URI: http://cloudworkthemes.com
* @link http://demo.cloudworkthemes.com/tracked
* @license GPL v3
* @license URI http://www.gnu.org/licenses/gpl.html 
* @since 1.0
*
*  	 Copyright (C) 2013  Chris Kelley (chris@organicbeemedia.com)
*
*    This program is free software: you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation, either version 3 of the License, or
*    (at your option) any later version.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU General Public License for more details.
*
*    You should have received a copy of the GNU General Public License
*    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
* 	 Some rights reserved. See COPYING, AUTHORS.
*
* 	Table of Contents
*	-----------------
*
*	Holds array of options
*
* 		cw_options 
*/
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * Set Theme Options.
 *
 * @since 1.1
 * @access public
 * @return array
 */
function cw_customizer_options() {

	$pagination_array = array(
		'next' => __('Next and Previous', 'cloudwork_themes'),
		'numerical' => __('Numerical', 'cloudwork_themes'),
	);

	$options = array();

	/* Logo settings go in the Site title and tagline area */
	$options[] = array(
		'type' => 'image',
		'id' => 'cw-logo',
		'section' => 'title_tagline',
		'priority' => '1',
		'capability' => 'edit_theme_options',
		'label' => __('Site Logo', 'cloudwork_themes'),
		'default' => '',
		'theme_supports' => '',
		'transport' => '',// this is the default
		);
	
	$options[] = array(
		'type' => 'checkbox',
		'id' => 'cw-retina-logo',
		'section' => 'title_tagline',
		'priority' => '2',
		'capability' => 'edit_theme_options',
		'label' => __('Retina Logo?', 'cloudwork_themes'),
		'default' => '0',// 0 or 1
		'theme_supports' => '',
		'transport' => '',// refresh (default) or postMessage 
		);
		
	$options[] = array(
		'type' => 'checkbox',
		'id' => 'cw_checkbox',
		'section' => 'title_tagline',
		'priority' => '3',
		'capability' => 'edit_theme_options',
		'label' => __('Display Tagline?', 'cloudwork_themes'),
		'default' => '0',// 0 or 1
		'theme_supports' => '',
		'transport' => '',// refresh (default) or postMessage 
		);
	
	/* Section Settings
	*  The setting section is a little different than setting up the other controls
	*/
	$options[] = array(
		'type' => 'section',
		'id' => 'cw_general',
		'title' => __('Theme Settings', 'cloudwork_themes'),
		'desc' => __('Theses are the settings for your current theme.', 'cloudwork_themes'),//displays as a tooltip on hover
		'priority' => '100',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',);

	$options[] = array(
		'type' => 'select',
		'id' => 'cw-pagination',
		'section' => 'cw_general',// This is the section the fields go in.
		'priority' => '2',
		'capability' => 'edit_theme_options',
		'label' => __('Pagination', 'cloudwork_themes'),
		'default' => 'numerical',
		'theme_supports' => '',
		'transport' => '',// this is the default
		'choices' => $pagination_array);
	
	$options[] = array(
		'type' => 'checkbox',
		'id' => 'cw_display_excerpt',
		'section' => 'cw_general',
		'priority' => '3',
		'capability' => 'edit_theme_options',
		'label' => __('Use Excerpt?', 'cloudwork_themes'),
		'default' => '0',// 0 or 1
		'theme_supports' => '',
		'transport' => '',// refresh (default) or postMessage 
		);	
	
	$options[] = array(
		'type' => 'text',
		'id' => 'cw_content_text',
		'section' => 'cw_general',// This is the section the fields go in.
		'priority' => '4',
		'capability' => 'edit_theme_options',
		'label' => __('More Text', 'cloudwork_themes'),
		'default' => 'Continue Reading',
		'theme_supports' => '',
		'transport' => '',// this is the default
		);

	$options[] = array(
		'type' => 'text',
		'id' => 'cw_excerpt_length',
		'section' => 'cw_general',// This is the section the fields go in.
		'priority' => '5',
		'capability' => 'edit_theme_options',
		'label' => __('Excerpt Length', 'cloudwork_themes'),
		'default' => '40',
		'theme_supports' => '',
		'transport' => '',// this is the default
		);

	$options[] = array(
		'type' => 'color',
		'id' => 'cw_link_color',
		'section' => 'cw_general',
		'priority' => '6',
		'capability' => 'edit_theme_options',
		'label' => __('Link Color', 'cloudwork_themes'),
		'default' => '#2c5da6',
		'theme_supports' => '',
		'transport' => '',// this is the default
		);
		
	$options[] = array(
		'type' => 'color',
		'id' => 'cw_link_hover',
		'section' => 'cw_general',
		'priority' => '7',
		'capability' => 'edit_theme_options',
		'label' => __('Link Hover Color', 'cloudwork_themes'),
		'default' => '#213e68',
		'theme_supports' => '',
		'transport' => '',// this is the default
		);
	if( cw_get_option('cw-custom-css') != '' ){
		
	$options[] = array(
		'type' => 'textarea',
		'id' => 'cw-custom-css',
		'section' => 'cw_general',// This is the section the fields go in.
		'priority' => '8',
		'capability' => 'edit_theme_options',
		'label' => __('Custom CSS', 'cloudwork_themes'),
		'default' => '40',
		'theme_supports' => '',
		'transport' => '',// this is the default
		);
	}
	if( cw_get_option('cw-custom-js') != '' ){

	$options[] = array(
		'type' => 'textarea',
		'id' => 'cw-custom-js',
		'section' => 'cw_general',// This is the section the fields go in.
		'priority' => '9',
		'capability' => 'edit_theme_options',
		'label' => __('Custom JS', 'cloudwork_themes'),
		'default' => '40',
		'theme_supports' => '',
		'transport' => '',// this is the default
		);	
		
	}
	
	return $options;
}

?>