<?php
/**
* @package Tracked
* @subpackage theme-scripts.php
* @author Chris Kelley <chris@organicbeemedia.com)
* @author URI: http://cloudworkthemes.com
* @link http://demo.cloudworkthemes.com/tracked
* @license GPL v3
* @license URI http://www.gnu.org/licenses/gpl.html 
* @since 1.0
*
*  	 Copyright (C) 2013  Chris Kelley (chris@organicbeemedia.com)
*
*    This program is free software: you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation, either version 3 of the License, or
*    (at your option) any later version.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU General Public License for more details.
*
*    You should have received a copy of the GNU General Public License
*    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
* 	 Some rights reserved. See COPYING, AUTHORS.
*
* 	Table of Contents
*	-----------------
*
* 		Class cloudwork_themesScripts
*			__construct
*			register_scripts
*			enqueue_styles
*			jquery_in_footer
*			enqueue_scripts
*			print_user_scripts
*/
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

if ( !class_exists( 'cloudwork_themesScripts' ) ) :

class cloudwork_themesScripts{
	
	function __construct(){
	
		add_action( 'init', array( $this, 'register_scripts' ));

		add_action( 'wp_enqueue_scripts', array( $this , 'enqueue_styles' ) , 1 );
				
		add_action('wp_enqueue_scripts', array( $this ,  'enqueue_scripts' ));

		add_action( 'wp_footer', array( $this , 'print_user_scripts' ) );
		
	}

	/**
	 * Registers all scripts
	 * 
	 * @access public
	 * @return void
	 */
	function register_scripts(){
	
		//Register main style.css for theme
		wp_register_style( 'cw-screen', get_bloginfo('stylesheet_url'), array(), THEMEVERSION , false  );
		
		wp_register_style( 'cw-font', 'http://fonts.googleapis.com/css?family=Roboto:300,300italic,500' , array(), THEMEVERSION , false  );	

		wp_register_script( 'cw-preload', trailingslashit( CW_JS ) . 'jquery.imgpreload.min.js', array('jquery'), '1.0' , true );
		
		wp_register_script( 'cw-mobile-events', trailingslashit( CW_JS ) . 'jgestures.min.js', array('jquery'), '1.0' , true );

		//Make sure custom scripts load after all jQuery plugins
		wp_register_script( 'cw-custom', trailingslashit( CW_JS ) . 'rite.custom.js', array('jquery', 'cw-fitvid', 'cw-audiojs', 'cw-flexislider' ), THEMEVERSION , true );
	
	}


	/**
	* Enqueue Theme Styles 
	*
	* @since 1.0
	* @access public
	* @return void
	*/
	function enqueue_styles() {

		if (is_admin()) {
	
			return;
	
		}
	
		if (!is_admin()) {
	
			//Load the main style.css
			wp_enqueue_style( 'cw-screen' );
		
			wp_enqueue_style( 'cw-font' );

			$cloudwork_themes_css = '';
			
			if( cw_get_option('cw_link_color' ) ) {
				
				$link_color = cw_get_option('cw_link_color'); 

				$cloudwork_themes_css .=" a { color: {$link_color};}";

			}
			
			if( cw_get_option('cw_link_hover' ) ) {
			
				$hover_color = cw_get_option('cw_link_hover'); 
			
				$cloudwork_themes_css .= " a:hover { color: {$hover_color};}";

			}
			//load the custom css below the style.css this will be removed in later versions and the Theme Utility will handle it.
			if( cw_get_option('cw-custom-css')){
		
				$cloudwork_themes_css .= cw_get_option('cw-custom-css');
				
	
			}
			if( cw_get_option('cw-custom-css') || cw_get_option('cw_link_color') || cw_get_option('cw_link_hover') ){
			
				wp_add_inline_style('cw-screen', $cloudwork_themes_css);
			
			}

		
		}		
	
	}


	/**
	* Enqueue all frontend scripts
	*
	* @since 1.0
	* @access public
	* @return void
	*/
	
	function enqueue_scripts() {

		if (is_admin()) {
		
			return;
	
		}
	
		// If we're not in admin, lets do fun stuff
		if (!is_admin()){
		
			wp_enqueue_script( 'jquery');
					
			wp_enqueue_script( 'cw-preload');

			wp_enqueue_script( 'cw-audiojs' );
				
			wp_enqueue_script( 'cw-flexislider' );
		
			wp_enqueue_script( 'cw-fitvid' );

			wp_enqueue_script( 'cw-mobile-events' );
			
			wp_enqueue_script( 'cw-custom' );		

			wp_localize_script( 'cw-custom', 'cwJSvars', array(
				
				'audiojs_url' => trailingslashit( CW_FLASH ) . 'audiojs.swf',
					
			) );
	
	
			if ( is_singular() and comments_open() and (get_option('thread_comments') == 1)){
		
				wp_enqueue_script( 'comment-reply' );
		
			}

		}
	
	}

	/**
	* Loads Custom JavaScript, user inputed via the theme options
	*
	* @since 1.0
	* @access public
	* @return void
	*/
	function print_user_scripts() {
	
		//Makes sure custom scripts have been loaded and the option is being used
		if ( wp_script_is( 'cw-custom', 'done' ) && cw_get_option('cw-custom-js') )  { 
		
			echo '<script>';
		
			echo cw_get_option('cw-custom-js'); 
		
			echo '</script>';
	
		}

	}
	
}//end class

endif;

$cloudwork_themes_scripts = new cloudwork_themesScripts();

?>